@@ -86,7 +86,7 @@
 #define KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED
-#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED_WARNINGS
 #  define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -163,6 +163,18 @@
 #else
 #  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_82(text)
 #endif
+
+#if KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_101(text) KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_101(text)
+#endif
+
+#if KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_102(text) KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_102(text)
+#endif
 #define KWINDOWSYSTEM_DEPRECATED_VERSION_5(minor, text)      KWINDOWSYSTEM_DEPRECATED_VERSION_5_##minor(text)
 #define KWINDOWSYSTEM_DEPRECATED_VERSION(major, minor, text) KWINDOWSYSTEM_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWINDOWSYSTEM_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWINDOWSYSTEM_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -228,7 +240,7 @@
 #define KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED
-#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED_WARNINGS
 #  define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0
@@ -238,7 +250,7 @@
 #  ifdef KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -305,6 +317,18 @@
 #else
 #  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_82(text)
 #endif
+
+#if KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_101(text) KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_101(text)
+#endif
+
+#if KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_102(text) KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_102(text)
+#endif
 #define KWINDOWSYSTEM_DEPRECATED_VERSION_5(minor, text)      KWINDOWSYSTEM_DEPRECATED_VERSION_5_##minor(text)
 #define KWINDOWSYSTEM_DEPRECATED_VERSION(major, minor, text) KWINDOWSYSTEM_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWINDOWSYSTEM_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWINDOWSYSTEM_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
